package repository

import (
	"ai-gateway/common/utils"
	"code.freebrio.com/fb-go/lib/context"
	"time"
)

// FThirdAgentCorpRelationDO 第三方 代理&企业 关系表
type FThirdAgentCorpRelationDO struct {
	Id           uint64    `gorm:"column:id;type:bigint(20) unsigned;primary_key;AUTO_INCREMENT" json:"id"`
	AgentId      uint64    `gorm:"column:agent_id;type:bigint(20) unsigned;comment:代理id;NOT NULL" json:"agent_id"`
	CorpId       uint64    `gorm:"column:corp_id;type:bigint(20) unsigned;comment:企业id;NOT NULL" json:"corp_id"`
	BizId        int64     `gorm:"column:biz_id;type:bigint(20);comment:业务id。 " json:"biz_id"`
	QualityLimit uint64    `gorm:"column:quality_limit;type:bigint(20) unsigned;default:0;comment:数量限制;NOT NULL" json:"quality_limit"`
	StartTime    uint64    `gorm:"column:start_time;type:bigint(20) unsigned;comment:开始时间;NOT NULL" json:"start_time"`
	EndTime      uint64    `gorm:"column:end_time;type:bigint(20) unsigned;comment:结束时间;NOT NULL" json:"end_time"`
	Deleted      uint      `gorm:"column:deleted;type:tinyint(1) unsigned;default:0;comment:逻辑删除。 0:未删除；1:已删除;NOT NULL" json:"deleted"`
	CreateTime   time.Time `gorm:"column:create_time;type:timestamp;default:CURRENT_TIMESTAMP;comment:创建时间;NOT NULL" json:"create_time"`
	UpdateTime   time.Time `gorm:"column:update_time;type:timestamp;default:CURRENT_TIMESTAMP;comment:更新时间;NOT NULL" json:"update_time"`
}

func (m *FThirdAgentCorpRelationDO) TableName() string {
	return "f_third_agent_corp_relation"
}

type thirdAgentCorpRepositoryImpl struct {
}

func (thirdAgentCorpRepositoryImpl) QueryPage(ctx context.GormWithZap, page, size int) *[]FThirdAgentCorpRelationDO {
	db, err := ctx.GormWithContext()
	if err != nil {
		return nil
	}

	offset := (page - 1) * size
	offset = utils.If(offset >= 0, offset, 0)
	var dataList []FThirdAgentCorpRelationDO
	sqlErr := db.Model(&FThirdAgentCorpRelationDO{}).Order("id DESC").Limit(size).Offset(offset).Find(&dataList).Error
	if sqlErr != nil {
		ctx.Zap().Sugar().Errorf("QueryPage_sqlErr page:%d %+v", page, sqlErr)
		return nil
	}

	if len(dataList) == 0 {
		return nil
	}

	return &dataList

}

func (thirdAgentCorpRepositoryImpl) FindById(ctx context.GormWithZap, id uint64) *FThirdAgentCorpRelationDO {
	db, err := ctx.GormWithContext()
	if err != nil {
		return nil
	}

	var model FThirdAgentCorpRelationDO
	sqlErr := db.Where("id=?", id).First(&model).Error
	if sqlErr != nil {
		ctx.Zap().Sugar().Errorf("FindById_sqlErr id:%d %+v", id, sqlErr)
		return nil
	}

	return &model
}

func (thirdAgentCorpRepositoryImpl) Count(ctx context.GormWithZap) int64 {
	db, err := ctx.GormWithContext()
	if err != nil {
		return 0
	}

	var total int64
	sqlErr := db.Model(&FThirdAgentCorpRelationDO{}).Select("count(*)").First(&total).Error
	if sqlErr != nil {
		ctx.Zap().Sugar().Errorf("Count_sqlErr  %+v", sqlErr)
		return 0
	}

	return total
}

func (thirdAgentCorpRepositoryImpl) Create(ctx context.GormWithZap, data *FThirdAgentCorpRelationDO) error {
	db, err := ctx.GormWithContext()
	if err != nil {
		return err
	}

	//保存数据
	return db.Create(data).Error
}

func (thirdAgentCorpRepositoryImpl) UpdateById(ctx context.GormWithZap, data FThirdAgentCorpRelationDO) error {
	db, err := ctx.GormWithContext()
	if err != nil {
		return err
	}

	//更新数据
	return db.Updates(&data).Error
}

func (thirdAgentCorpRepositoryImpl) deleteById(ctx context.GormWithZap, id uint64, operator string) error {
	db, err := ctx.GormWithContext()
	if err != nil {
		return err
	}

	data := FThirdAgentCorpRelationDO{}
	sqlErr := db.Model(&data).
		Select("deleted").
		Where("id=?", id).
		Updates(FThirdAgentCorpRelationDO{Deleted: 1}).Error
	if sqlErr != nil {
		return sqlErr
	}

	return nil
}
