package repository

import (
	"code.freebrio.com/fb-go/lib/context"
	"time"
)

// FThirdCorpUserLogDO 第三方 企业用户 日志表
type FThirdCorpUserLogDO struct {
	Id         uint64    `gorm:"column:id;type:bigint(20) unsigned;primary_key;AUTO_INCREMENT" json:"id"`
	CorpId     uint64    `gorm:"column:corp_id;type:bigint(20) unsigned;comment:企业id;NOT NULL" json:"corp_id"`
	BizId      int64     `gorm:"column:biz_id;type:bigint(20);comment:业务id。 " json:"biz_id"`
	CorpUid    uint64    `gorm:"column:corp_uid;type:bigint(20) unsigned;comment:企业uid;NOT NULL" json:"corp_uid"`
	BizContext string    `gorm:"column:biz_context;type:json;comment:业务内容 " json:"biz_context"`
	CreateTime time.Time `gorm:"column:create_time;type:timestamp;default:CURRENT_TIMESTAMP;comment:创建时间;NOT NULL" json:"create_time"`
	UpdateTime time.Time `gorm:"column:update_time;type:timestamp;default:CURRENT_TIMESTAMP;comment:更新时间;NOT NULL" json:"update_time"`
}

func (m *FThirdCorpUserLogDO) TableName() string {
	return "f_third_corp_user_log"
}

type thirdCorpUserLogRepositoryImpl struct {
}

func (thirdCorpUserLogRepositoryImpl) QueryList(ctx context.GormWithZap, id uint64, size int) *[]FThirdCorpUserLogDO {
	db, err := ctx.GormWithContext()
	if err != nil {
		return nil
	}

	var dataList []FThirdCorpUserLogDO
	sqlErr := db.Model(&FThirdCorpUserLogDO{}).Where("id>?", id).Order("id DESC").Limit(size).Find(&dataList).Error
	if sqlErr != nil {
		ctx.Zap().Sugar().Errorf("QueryList_sqlErr id:%d %+v", id, sqlErr)
		return nil
	}

	if len(dataList) == 0 {
		return nil
	}

	return &dataList
}

func (thirdCorpUserLogRepositoryImpl) FindById(ctx context.GormWithZap, id uint64) *FThirdCorpUserLogDO {
	db, err := ctx.GormWithContext()
	if err != nil {
		return nil
	}

	var model FThirdCorpUserLogDO
	sqlErr := db.Where("id=?", id).First(&model).Error
	if sqlErr != nil {
		ctx.Zap().Sugar().Errorf("FindById_sqlErr id:%d %+v", id, sqlErr)
		return nil
	}

	return &model
}

func (thirdCorpUserLogRepositoryImpl) Create(ctx context.GormWithZap, data *FThirdCorpUserLogDO) error {
	db, err := ctx.GormWithContext()
	if err != nil {
		return err
	}

	//保存数据
	return db.Create(data).Error
}
